@@ -33,8 +33,8 @@
 #include <QMessageBox>
 #include <QSettings>
 #include <QTextStream>
-#include <QTextCodec>
 #include <QFileInfo>
+#include <QRegularExpression>
 
 #define SA(x) QString::fromLatin1(x)
 
@@ -223,11 +223,14 @@ static QString getDocsForNode(const QDomElement &child)
       }
       docsVal = docsVal.nextSiblingElement();
     }
-    docs+=SA("<br/>");
-    docs+=SA("<br/>");
-    docs+=SA(" The default value is: <code>")+
-          child.attribute(SA("defval"))+
-          SA("</code>.");
+    if (child.attribute(SA("defval")) != SA(""))
+    {
+      docs+=SA("<br/>");
+      docs+=SA("<br/>");
+      docs+=SA(" The default value is: <code>")+
+            child.attribute(SA("defval"))+
+            SA("</code>.");
+    }
     docs+= SA("<br/>");
   }
   else if (type==SA("int"))
@@ -404,7 +407,7 @@ static QString getDocsForNode(const QDomElement &child)
   // Remove / replace doxygen markup strings
   // the regular expressions are hard to read so the intention will be given
   // Note: see also configgen.py in the src directory for other doxygen parts
-  QRegExp regexp;
+  QRegularExpression regexp;
   // remove \n at end and replace by a space
   regexp.setPattern(SA("\\n$"));
   docs.replace(regexp,SA(" "));
@@ -785,7 +788,7 @@ void Expert::loadConfig(const QString &fileName)
   parseConfig(fileName,m_options);
 }
 
-void Expert::saveTopic(QTextStream &t,QDomElement &elem,QTextCodec *codec,
+void Expert::saveTopic(QTextStream &t,QDomElement &elem,TextCodecAdapter *codec,
                        bool brief,bool condensed)
 {
   if (!brief)
@@ -847,22 +850,14 @@ bool Expert::writeConfig(QTextStream &t,bool brief, bool condensed)
     t << convertToComment(m_header);
   }
 
-  QTextCodec *codec = 0;
   Input *option = m_options[QString::fromLatin1("DOXYFILE_ENCODING")];
-  if (option)
-  {
-    codec = QTextCodec::codecForName(option->value().toString().toLatin1());
-    if (codec==0) // fallback: use UTF-8
-    {
-      codec = QTextCodec::codecForName("UTF-8");
-    }
-  }
+  TextCodecAdapter codec(option->value().toString().toLatin1());
   QDomElement childElem = m_rootElement.firstChildElement();
   while (!childElem.isNull())
   {
     if (childElem.tagName()==SA("group"))
     {
-      saveTopic(t,childElem,codec,brief,condensed);
+      saveTopic(t,childElem,&codec,brief,condensed);
     }
     childElem = childElem.nextSiblingElement();
   }
