@@ -147,8 +147,6 @@ DocbookCodeGenerator::DocbookCodeGenerator(TextStream &t) : m_t(t)
 {
 }
 
-DocbookCodeGenerator::~DocbookCodeGenerator() {}
-
 void DocbookCodeGenerator::codify(const QCString &text)
 {
   Docbook_DB(("(codify \"%s\")\n",text));
@@ -253,14 +251,6 @@ void DocbookCodeGenerator::writeLineNumber(const QCString &ref,const QCString &f
   m_col=0;
 }
 
-void DocbookCodeGenerator::setCurrentDoc(const Definition *,const QCString &,bool)
-{
-}
-
-void DocbookCodeGenerator::addWord(const QCString &,bool)
-{
-}
-
 void DocbookCodeGenerator::finish()
 {
   endCodeLine();
@@ -283,12 +273,16 @@ DB_GEN_C1(m_t)
 
 //-------------------------------------------------------------------------------
 
-DocbookGenerator::DocbookGenerator() : OutputGenerator(Config_getString(DOCBOOK_OUTPUT)), m_codeGen(m_t)
+DocbookGenerator::DocbookGenerator()
+  : OutputGenerator(Config_getString(DOCBOOK_OUTPUT))
+  , m_codeGen(m_t)
 {
 DB_GEN_C
 }
 
-DocbookGenerator::DocbookGenerator(const DocbookGenerator &og) : OutputGenerator(og), m_codeGen(m_t)
+DocbookGenerator::DocbookGenerator(const DocbookGenerator &og)
+  : OutputGenerator(og)
+  , m_codeGen(m_t)
 {
 }
 
@@ -345,7 +339,7 @@ DB_GEN_C
   }
   pageName = fileName;
   relPath = relativePathToRoot(fileName);
-  if (fileName.right(4)!=".xml") fileName+=".xml";
+  if (!fileName.endsWith(".xml")) fileName+=".xml";
   startPlainFile(fileName);
   m_codeGen.setRelativePath(relPath);
   m_codeGen.setSourceFileName(stripPath(fileName));
@@ -379,12 +373,12 @@ DB_GEN_C
   m_codeGen.setSourceFileName("");
 }
 
-void DocbookGenerator::startIndexSection(IndexSections is)
+void DocbookGenerator::startIndexSection(IndexSection is)
 {
-DB_GEN_C2("IndexSections " << is)
+DB_GEN_C2("IndexSection " << is)
   switch (is)
   {
-    case isTitlePageStart:
+    case IndexSection::isTitlePageStart:
       {
         QCString dbk_projectName = Config_getString(PROJECT_NAME);
         m_t << "    <info>\n";
@@ -392,118 +386,118 @@ DB_GEN_C2("IndexSections " << is)
         m_t << "    </info>\n";
       }
       break;
-    case isTitlePageAuthor:
+    case IndexSection::isTitlePageAuthor:
       break;
-    case isMainPage:
+    case IndexSection::isMainPage:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isModuleIndex:
-      //Module Index}\n"
+    case IndexSection::isModuleIndex:
+      //Module Index\n"
       break;
-    case isDirIndex:
-      //Directory Index}\n"
+    case IndexSection::isDirIndex:
+      //Directory Index\n"
       break;
-    case isNamespaceIndex:
-      //Namespace Index}\n"
+    case IndexSection::isNamespaceIndex:
+      //Namespace Index\n"
       break;
-    case isConceptIndex:
-      //Concept Index}\n"
+    case IndexSection::isConceptIndex:
+      //Concept Index\n"
       break;
-    case isClassHierarchyIndex:
-      //Hierarchical Index}\n"
+    case IndexSection::isClassHierarchyIndex:
+      //Hierarchical Index\n"
       break;
-    case isCompoundIndex:
+    case IndexSection::isCompoundIndex:
       //m_t << "{"; //Class Index}\n"
       break;
-    case isFileIndex:
-      //Annotated File Index}\n"
+    case IndexSection::isFileIndex:
+      //Annotated File Index\n"
       break;
-    case isPageIndex:
-      //Annotated Page Index}\n"
+    case IndexSection::isPageIndex:
+      //Annotated Page Index\n"
       break;
-    case isModuleDocumentation:
+    case IndexSection::isModuleDocumentation:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isDirDocumentation:
+    case IndexSection::isDirDocumentation:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isNamespaceDocumentation:
+    case IndexSection::isNamespaceDocumentation:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isConceptDocumentation:
+    case IndexSection::isConceptDocumentation:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isClassDocumentation:
+    case IndexSection::isClassDocumentation:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isFileDocumentation:
+    case IndexSection::isFileDocumentation:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isExampleDocumentation:
+    case IndexSection::isExampleDocumentation:
       m_t << "<chapter>\n";
       m_t << "    <title>";
       break;
-    case isPageDocumentation:
+    case IndexSection::isPageDocumentation:
       break;
-    case isPageDocumentation2:
+    case IndexSection::isPageDocumentation2:
       break;
-    case isEndIndex:
+    case IndexSection::isEndIndex:
       break;
   }
 }
 
-void DocbookGenerator::endIndexSection(IndexSections is)
+void DocbookGenerator::endIndexSection(IndexSection is)
 {
-DB_GEN_C2("IndexSections " << is)
+DB_GEN_C2("IndexSection " << is)
   switch (is)
   {
-    case isTitlePageStart:
+    case IndexSection::isTitlePageStart:
       break;
-    case isTitlePageAuthor:
+    case IndexSection::isTitlePageAuthor:
       break;
-    case isMainPage:
+    case IndexSection::isMainPage:
       m_t << "</title>\n";
       m_t << "    <xi:include href=\"mainpage.xml\" xmlns:xi=\"http://www.w3.org/2001/XInclude\"/>\n";
       m_t << "</chapter>\n";
       break;
-    case isModuleIndex:
+    case IndexSection::isModuleIndex:
       //m_t << "</chapter>\n";
       break;
-    case isDirIndex:
+    case IndexSection::isDirIndex:
       //m_t << "<xi:include href=\"dirs.xml\" xmlns:xi=\"http://www.w3.org/2001/XInclude\"/>";
       //m_t << "</chapter>\n";
       break;
-    case isNamespaceIndex:
+    case IndexSection::isNamespaceIndex:
       //m_t << "<xi:include href=\"namespaces.xml\" xmlns:xi=\"http://www.w3.org/2001/XInclude\"/>";
       //m_t << "</chapter>\n";
       break;
-    case isConceptIndex:
+    case IndexSection::isConceptIndex:
       //m_t << "<xi:include href=\"concepts.xml\" xmlns:xi=\"http://www.w3.org/2001/XInclude\"/>";
       //m_t << "</chapter>\n";
       break;
-    case isClassHierarchyIndex:
+    case IndexSection::isClassHierarchyIndex:
       //m_t << "<xi:include href=\"hierarchy.xml\" xmlns:xi=\"http://www.w3.org/2001/XInclude\"/>";
       //m_t << "</chapter>\n";
       break;
-    case isCompoundIndex:
+    case IndexSection::isCompoundIndex:
       //m_t << "</chapter>\n";
       break;
-    case isFileIndex:
+    case IndexSection::isFileIndex:
       //m_t << "<xi:include href=\"files.xml\" xmlns:xi=\"http://www.w3.org/2001/XInclude\"/>";
       //m_t << "</chapter>\n";
       break;
-    case isPageIndex:
+    case IndexSection::isPageIndex:
       //m_t << "<xi:include href=\"pages.xml\" xmlns:xi=\"http://www.w3.org/2001/XInclude\"/>";
       //m_t << "</chapter>\n";
       break;
-    case isModuleDocumentation:
+    case IndexSection::isModuleDocumentation:
       {
         m_t << "</title>\n";
         for (const auto &gd : *Doxygen::groupLinkedMap)
@@ -516,7 +510,7 @@ DB_GEN_C2("IndexSections " << is)
       }
       m_t << "</chapter>\n";
       break;
-    case isDirDocumentation:
+    case IndexSection::isDirDocumentation:
       {
         m_t << "</title>\n";
         for (const auto &dd : *Doxygen::dirLinkedMap)
@@ -529,7 +523,7 @@ DB_GEN_C2("IndexSections " << is)
       }
       m_t << "</chapter>\n";
       break;
-    case isNamespaceDocumentation:
+    case IndexSection::isNamespaceDocumentation:
       {
         m_t << "</title>\n";
         for (const auto &nd : *Doxygen::namespaceLinkedMap)
@@ -542,7 +536,7 @@ DB_GEN_C2("IndexSections " << is)
       }
       m_t << "</chapter>\n";
       break;
-    case isConceptDocumentation:
+    case IndexSection::isConceptDocumentation:
       {
         m_t << "</title>\n";
         for (const auto &cd : *Doxygen::conceptLinkedMap)
@@ -555,7 +549,7 @@ DB_GEN_C2("IndexSections " << is)
       }
       m_t << "</chapter>\n";
       break;
-    case isClassDocumentation:
+    case IndexSection::isClassDocumentation:
       {
         m_t << "</title>\n";
         for (const auto &cd : *Doxygen::classLinkedMap)
@@ -572,7 +566,7 @@ DB_GEN_C2("IndexSections " << is)
       }
       m_t << "</chapter>\n";
       break;
-    case isFileDocumentation:
+    case IndexSection::isFileDocumentation:
       {
         m_t << "</title>\n";
         for (const auto &fn : *Doxygen::inputNameLinkedMap)
@@ -592,7 +586,7 @@ DB_GEN_C2("IndexSections " << is)
       }
       m_t << "</chapter>\n";
       break;
-    case isExampleDocumentation:
+    case IndexSection::isExampleDocumentation:
       {
         m_t << "</title>\n";
         for (const auto &pd : *Doxygen::exampleLinkedMap)
@@ -602,11 +596,11 @@ DB_GEN_C2("IndexSections " << is)
       }
       m_t << "</chapter>\n";
       break;
-    case isPageDocumentation:
+    case IndexSection::isPageDocumentation:
       break;
-    case isPageDocumentation2:
+    case IndexSection::isPageDocumentation2:
       break;
-    case isEndIndex:
+    case IndexSection::isEndIndex:
       m_t << "<index/>\n";
       break;
   }
@@ -633,13 +627,15 @@ DB_GEN_C
   }
 }
 
-void DocbookGenerator::writeDoc(DocNode *n,const Definition *ctx,const MemberDef *,int)
+void DocbookGenerator::writeDoc(const IDocNodeAST *ast,const Definition *ctx,const MemberDef *,int)
 {
 DB_GEN_C
-  DocbookDocVisitor *visitor =
-    new DocbookDocVisitor(m_t,*this,ctx?ctx->getDefFileExtension():QCString());
-  n->accept(visitor);
-  delete visitor;
+  auto astImpl = dynamic_cast<const DocNodeAST*>(ast);
+  if (astImpl)
+  {
+    DocbookDocVisitor visitor(m_t,m_codeGen,ctx?ctx->getDefFileExtension():QCString());
+    std::visit(visitor,astImpl->root);
+  }
 }
 
 void DocbookGenerator::startParagraph(const QCString &)
@@ -676,21 +672,29 @@ void DocbookGenerator::docify(const QCString &str)
 DB_GEN_C
   m_t << convertToDocBook(str);
 }
-void DocbookGenerator::writeObjectLink(const QCString &, const QCString &f,
-                                     const QCString &anchor, const QCString &text)
+static QCString objectLinkToString(const QCString &, const QCString &f,
+                                   const QCString &anchor, const QCString &text)
 {
 DB_GEN_C
+  QCString result;
   if (!anchor.isEmpty())
   {
-    if (!f.isEmpty()) m_t << "<link linkend=\"_" << stripPath(f) << "_1" << anchor << "\">";
-    else   m_t << "<link linkend=\"_" << anchor << "\">";
+    if (!f.isEmpty()) result += "<link linkend=\"_" + stripPath(f) + "_1" + anchor + "\">";
+    else   result += "<link linkend=\"_" + anchor + "\">";
   }
   else
   {
-    m_t << "<link linkend=\"_" << stripPath(f) << "\">";
+    result += "<link linkend=\"_" + stripPath(f) + "\">";
   }
-  docify(text);
-  m_t << "</link>";
+  result += convertToDocBook(text);
+  result += "</link>";
+  return result;
+}
+void DocbookGenerator::writeObjectLink(const QCString &ref, const QCString &f,
+                                     const QCString &anchor, const QCString &text)
+{
+DB_GEN_C
+  m_t << objectLinkToString(ref,f,anchor,text);
 }
 void DocbookGenerator::startMemberList()
 {
@@ -769,12 +773,12 @@ DB_GEN_C
 void DocbookGenerator::writeNonBreakableSpace(int n)
 {
 DB_GEN_C
-  for (int i=0;i<n;i++) m_t << " ";
+  for (int i=0;i<n;i++) m_t << "&#160;";
 }
 void DocbookGenerator::lineBreak(const QCString &)
 {
 DB_GEN_C
-  m_t << "\n";
+  m_t << "<?linebreak?>";
 }
 void DocbookGenerator::startTypewriter()
 {
@@ -1261,3 +1265,11 @@ void DocbookGenerator::closeAllSections()
   }
 }
 
+void DocbookGenerator::writeInheritedSectionTitle(
+                  const QCString &id,    const QCString &ref,
+                  const QCString &file,  const QCString &anchor,
+                  const QCString &title, const QCString &name)
+{
+DB_GEN_C
+  m_t << theTranslator->trInheritedFrom(convertToDocBook(title), objectLinkToString(ref, file, anchor, name));
+}
