@@ -13,8 +13,6 @@
  *
  */
 
-#include <fstream>
-
 #include "docbookvisitor.h"
 #include "docparser.h"
 #include "language.h"
@@ -35,6 +33,7 @@
 #include "plantuml.h"
 #include "growbuf.h"
 #include "fileinfo.h"
+#include "portable.h"
 
 #if 0
 #define DB_VIS_C DB_VIS_C1(m_t)
@@ -203,14 +202,14 @@ void DocbookDocVisitor::operator()(const DocSymbol &s)
 {
 DB_VIS_C
   if (m_hide) return;
-  const char *res = HtmlEntityMapper::instance()->docbook(s.symbol());
+  const char *res = HtmlEntityMapper::instance().docbook(s.symbol());
   if (res)
   {
     m_t << res;
   }
   else
   {
-    err("DocBook: non supported HTML-entity found: %s\n",HtmlEntityMapper::instance()->html(s.symbol(),TRUE));
+    err("DocBook: non supported HTML-entity found: %s\n",HtmlEntityMapper::instance().html(s.symbol(),TRUE));
   }
 }
 
@@ -218,7 +217,7 @@ void DocbookDocVisitor::operator()(const DocEmoji &s)
 {
 DB_VIS_C
   if (m_hide) return;
-  const char *res = EmojiEntityMapper::instance()->unicode(s.index());
+  const char *res = EmojiEntityMapper::instance().unicode(s.index());
   if (res)
   {
     m_t << res;
@@ -306,9 +305,6 @@ DB_VIS_C
     case DocStyleChange::Ins:        break;
     case DocStyleChange::Div:  /* HTML only */ break;
     case DocStyleChange::Span: /* HTML only */ break;
-    case DocStyleChange::Summary: /* emulation of the <summary> tag inside a <details> tag */
-      if (s.enable()) m_t << "<para><emphasis role=\"bold\">";      else m_t << "</emphasis></para>";
-      break;
   }
 }
 
@@ -371,17 +367,17 @@ DB_VIS_C
             qPrint(Config_getString(DOCBOOK_OUTPUT)+"/inline_dotgraph_"),
             dotindex++
             );
-        std::string fileName = baseName.str()+".dot";
-        std::ofstream file(fileName,std::ofstream::out | std::ofstream::binary);
+        QCString fileName = baseName+".dot";
+        std::ofstream file = Portable::openOutputStream(fileName);
         if (!file.is_open())
         {
-          err("Could not open file %s for writing\n",fileName.c_str());
+          err("Could not open file %s for writing\n",qPrint(fileName));
         }
         file.write( stext.data(), stext.length() );
         file.close();
         writeDotFile(baseName, s);
         m_t << "</para>\n";
-        if (Config_getBool(DOT_CLEANUP)) Dir().remove(fileName);
+        if (Config_getBool(DOT_CLEANUP)) Dir().remove(fileName.str());
       }
       break;
     case DocVerbatim::Msc:
@@ -396,11 +392,11 @@ DB_VIS_C
             (Config_getString(DOCBOOK_OUTPUT)+"/inline_mscgraph_").data(),
             mscindex++
             );
-        std::string fileName = baseName.str()+".msc";
-        std::ofstream file(fileName,std::ofstream::out | std::ofstream::binary);
+        QCString fileName = baseName+".msc";
+        std::ofstream file = Portable::openOutputStream(fileName);
         if (!file.is_open())
         {
-          err("Could not open file %s for writing\n",fileName.c_str());
+          err("Could not open file %s for writing\n",qPrint(fileName));
         }
         QCString text = "msc {";
         text+=stext;
@@ -409,7 +405,7 @@ DB_VIS_C
         file.close();
         writeMscFile(baseName,s);
         m_t << "</para>\n";
-        if (Config_getBool(DOT_CLEANUP)) Dir().remove(fileName);
+        if (Config_getBool(DOT_CLEANUP)) Dir().remove(fileName.str());
       }
       break;
     case DocVerbatim::PlantUML:
@@ -1172,11 +1168,25 @@ DB_VIS_C
   m_t << "</link>";
 }
 
+void DocbookDocVisitor::operator()(const DocHtmlSummary &s)
+{
+DB_VIS_C
+  if (m_hide) return;
+  m_t << "<para><emphasis role=\"bold\">";
+  visitChildren(s);
+  m_t << "</emphasis></para>";
+}
+
 void DocbookDocVisitor::operator()(const DocHtmlDetails &d)
 {
 DB_VIS_C
   if (m_hide) return;
   m_t << "\n";
+  auto summary = d.summary();
+  if (summary)
+  {
+    std::visit(*this,*summary);
+  }
   m_t << "<para>";
   visitChildren(d);
   m_t << "</para>";
