@@ -230,7 +230,7 @@ class Entry
      */
     void reset();
 
-    void markAsProcessed() const { ((Entry*)(this))->section = Entry::EMPTY_SEC; }
+    void markAsProcessed() const { (const_cast<Entry*>(this))->section = Entry::EMPTY_SEC; }
     void setFileDef(FileDef *fd);
     FileDef *fileDef() const { return m_fileDef; }
 
@@ -299,6 +299,7 @@ class Entry
     LocalToc    localToc;
     QCString    metaData;     //!< Slice metadata
     QCString    req;          //!< C++20 requires clause
+    std::vector<std::string> qualifiers;  //!< qualifiers specified with the qualifier command
 
     /// return the command name used to define GROUPDOC_SEC
     const char *groupDocCmd() const
