@@ -25,13 +25,15 @@
 
 class TextStream;
 
+/** Generator for LaTeX code fragments */
 class LatexCodeGenerator : public CodeOutputInterface
 {
   public:
     LatexCodeGenerator(TextStream &t,const QCString &relPath,const QCString &sourceFile);
     LatexCodeGenerator(TextStream &t);
-    void setRelativePath(const QCString &path);
-    void setSourceFileName(const QCString &sourceFileName);
+
+    virtual OutputType type() const override { return OutputType::Latex; }
+
     void codify(const QCString &text) override;
     void writeCodeLink(CodeSymbolType type,
                        const QCString &ref,const QCString &file,
@@ -50,8 +52,6 @@ class LatexCodeGenerator : public CodeOutputInterface
     void startFontClass(const QCString &) override;
     void endFontClass() override;
     void writeCodeAnchor(const QCString &) override {}
-    void setCurrentDoc(const Definition *,const QCString &,bool) override {}
-    void addWord(const QCString &,bool) override {}
     void startCodeFragment(const QCString &style) override;
     void endCodeFragment(const QCString &style) override;
 
@@ -60,6 +60,9 @@ class LatexCodeGenerator : public CodeOutputInterface
     void decUsedTableLevel() { m_usedTableLevel--; }
     int usedTableLevel() const { return m_usedTableLevel; }
 
+    void setRelativePath(const QCString &path);
+    void setSourceFileName(const QCString &sourceFileName);
+
   private:
     void _writeCodeLink(const QCString &className,
                         const QCString &ref,const QCString &file,
@@ -76,7 +79,7 @@ class LatexCodeGenerator : public CodeOutputInterface
 };
 
 /** Generator for LaTeX output. */
-class LatexGenerator : public OutputGenerator
+class LatexGenerator : public OutputGenerator //: public CodeOutputForwarder<OutputGenerator,LatexCodeGenerator>
 {
   public:
     LatexGenerator();
@@ -91,40 +94,9 @@ class LatexGenerator : public OutputGenerator
     static void writeHeaderFile(TextStream &t);
     static void writeFooterFile(TextStream &t);
 
-    virtual OutputType type() const { return Latex; }
+    virtual OutputType type() const { return OutputType::Latex; }
 
-    // --- CodeOutputInterface
-    void codify(const QCString &text)
-    { m_codeGen.codify(text); }
-    void writeCodeLink(CodeSymbolType type,
-                       const QCString &ref, const QCString &file,
-                       const QCString &anchor,const QCString &name,
-                       const QCString &tooltip)
-    { m_codeGen.writeCodeLink(type,ref,file,anchor,name,tooltip); }
-    void writeLineNumber(const QCString &ref,const QCString &file,const QCString &anchor,int lineNumber, bool writeLineAnchor)
-    { m_codeGen.writeLineNumber(ref,file,anchor,lineNumber,writeLineAnchor); }
-    void writeTooltip(const QCString &id, const DocLinkInfo &docInfo, const QCString &decl,
-                      const QCString &desc, const SourceLinkInfo &defInfo, const SourceLinkInfo &declInfo
-                     )
-    { m_codeGen.writeTooltip(id,docInfo,decl,desc,defInfo,declInfo); }
-    void startCodeLine(bool hasLineNumbers)
-    { m_codeGen.startCodeLine(hasLineNumbers); }
-    void endCodeLine()
-    { m_codeGen.endCodeLine(); }
-    void startFontClass(const QCString &s)
-    { m_codeGen.startFontClass(s); }
-    void endFontClass()
-    { m_codeGen.endFontClass(); }
-    void writeCodeAnchor(const QCString &anchor)
-    { m_codeGen.writeCodeAnchor(anchor); }
-    void startCodeFragment(const QCString &style)
-    { m_codeGen.startCodeFragment(style); }
-    void endCodeFragment(const QCString &style)
-    { m_codeGen.endCodeFragment(style); }
-    // ---------------------------
-
-
-    void writeDoc(DocNode *,const Definition *ctx,const MemberDef *,int id);
+    void writeDoc(const IDocNodeAST *node,const Definition *ctx,const MemberDef *,int id);
 
     void startFile(const QCString &name,const QCString &manName,const QCString &title,int id);
     void writeSearchInfo() {}
@@ -132,8 +104,8 @@ class LatexGenerator : public OutputGenerator
     void endFile();
     void clearBuffer();
 
-    void startIndexSection(IndexSections);
-    void endIndexSection(IndexSections);
+    void startIndexSection(IndexSection);
+    void endIndexSection(IndexSection);
     void writePageLink(const QCString &,bool);
     void startProjectNumber();
     void endProjectNumber() {}
@@ -240,7 +212,7 @@ class LatexGenerator : public OutputGenerator
     void startMemberDeclaration() {}
     void endMemberDeclaration(const QCString &,const QCString &) {}
     void writeInheritedSectionTitle(const QCString &,const QCString &,const QCString &,
-                      const QCString &,const QCString &,const QCString &) {}
+                      const QCString &,const QCString &,const QCString &);
     void startDescList(SectionTypes)     { m_t << "\\begin{Desc}\n\\item["; }
     void endDescList()       { m_t << "\\end{Desc}\n"; }
     void startExamples();
@@ -332,6 +304,7 @@ class LatexGenerator : public OutputGenerator
     void setCurrentDoc(const Definition *,const QCString &,bool) {}
     void addWord(const QCString &,bool) {}
 
+    CodeOutputInterface *codeGen() { return &m_codeGen; }
 
   private:
     bool m_insideTabbing = false;
