@@ -32,7 +32,7 @@ ManListItemInfo man_listItemInfo[man_maxIndentLevels];
 
 ManDocVisitor::ManDocVisitor(TextStream &t,CodeOutputInterface &ci,
                              const QCString &langExt)
-  : DocVisitor(DocVisitor_Man), m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE), m_firstCol(FALSE),
+  : m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE), m_firstCol(FALSE),
     m_indent(0), m_langExt(langExt)
 {
 }
@@ -41,29 +41,29 @@ ManDocVisitor::ManDocVisitor(TextStream &t,CodeOutputInterface &ci,
   // visitor functions for leaf nodes
   //--------------------------------------
 
-void ManDocVisitor::visit(DocWord *w)
+void ManDocVisitor::operator()(const DocWord &w)
 {
   if (m_hide) return;
-  filter(w->word());
+  filter(w.word());
   m_firstCol=FALSE;
 }
 
-void ManDocVisitor::visit(DocLinkedWord *w)
+void ManDocVisitor::operator()(const DocLinkedWord &w)
 {
   if (m_hide) return;
   m_t << "\\fB";
-  filter(w->word());
+  filter(w.word());
   m_t << "\\fP";
   m_firstCol=FALSE;
 }
 
-void ManDocVisitor::visit(DocWhiteSpace *w)
+void ManDocVisitor::operator()(const DocWhiteSpace &w)
 {
   if (m_hide) return;
   if (m_insidePre)
   {
-    m_t << w->chars();
-    m_firstCol=w->chars().at(w->chars().length()-1)=='\n';
+    m_t << w.chars();
+    m_firstCol=w.chars().at(w.chars().length()-1)=='\n';
   }
   else
   {
@@ -72,10 +72,10 @@ void ManDocVisitor::visit(DocWhiteSpace *w)
   }
 }
 
-void ManDocVisitor::visit(DocSymbol *s)
+void ManDocVisitor::operator()(const DocSymbol &s)
 {
   if (m_hide) return;
-  const char *res = HtmlEntityMapper::instance()->man(s->symbol());
+  const char *res = HtmlEntityMapper::instance().man(s.symbol());
   if (res)
   {
     m_t << res;
@@ -88,36 +88,36 @@ void ManDocVisitor::visit(DocSymbol *s)
   m_firstCol=FALSE;
 }
 
-void ManDocVisitor::visit(DocEmoji *s)
+void ManDocVisitor::operator()(const DocEmoji &s)
 {
   if (m_hide) return;
-  const char *res = EmojiEntityMapper::instance()->name(s->index());
+  const char *res = EmojiEntityMapper::instance().name(s.index());
   if (res)
   {
     m_t << res;
   }
   else
   {
-    m_t << s->name();
+    m_t << s.name();
   }
   m_firstCol=FALSE;
 }
 
-void ManDocVisitor::visit(DocURL *u)
+void ManDocVisitor::operator()(const DocURL &u)
 {
   if (m_hide) return;
-  m_t << u->url();
+  m_t << u.url();
   m_firstCol=FALSE;
 }
 
-void ManDocVisitor::visit(DocLineBreak *)
+void ManDocVisitor::operator()(const DocLineBreak &)
 {
   if (m_hide) return;
   m_t << "\n.br\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visit(DocHorRuler *)
+void ManDocVisitor::operator()(const DocHorRuler &)
 {
   if (m_hide) return;
   if (!m_firstCol) m_t << "\n";
@@ -125,13 +125,13 @@ void ManDocVisitor::visit(DocHorRuler *)
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visit(DocStyleChange *s)
+void ManDocVisitor::operator()(const DocStyleChange &s)
 {
   if (m_hide) return;
-  switch (s->style())
+  switch (s.style())
   {
     case DocStyleChange::Bold:
-      if (s->enable()) m_t << "\\fB";      else m_t << "\\fP";
+      if (s.enable()) m_t << "\\fB";      else m_t << "\\fP";
       m_firstCol=FALSE;
       break;
     case DocStyleChange::S:
@@ -141,23 +141,23 @@ void ManDocVisitor::visit(DocStyleChange *s)
       break;
     case DocStyleChange::Underline: //underline is shown as emphasis
     case DocStyleChange::Ins:
-      if (s->enable()) m_t << "\\fI";     else m_t << "\\fP";
+      if (s.enable()) m_t << "\\fI";     else m_t << "\\fP";
       m_firstCol=FALSE;
       break;
     case DocStyleChange::Italic:
-      if (s->enable()) m_t << "\\fI";     else m_t << "\\fP";
+      if (s.enable()) m_t << "\\fI";     else m_t << "\\fP";
       m_firstCol=FALSE;
       break;
     case DocStyleChange::Code:
-      if (s->enable()) m_t << "\\fC";   else m_t << "\\fP";
+      if (s.enable()) m_t << "\\fC";   else m_t << "\\fP";
       m_firstCol=FALSE;
       break;
     case DocStyleChange::Subscript:
-      if (s->enable()) m_t << "\\*<";    else m_t << "\\*> ";
+      if (s.enable()) m_t << "\\*<";    else m_t << "\\*> ";
       m_firstCol=FALSE;
       break;
     case DocStyleChange::Superscript:
-      if (s->enable()) m_t << "\\*{";    else m_t << "\\*} ";
+      if (s.enable()) m_t << "\\*{";    else m_t << "\\*} ";
       m_firstCol=FALSE;
       break;
     case DocStyleChange::Center:
@@ -170,7 +170,7 @@ void ManDocVisitor::visit(DocStyleChange *s)
       /* not supported */
       break;
     case DocStyleChange::Preformatted:
-      if (s->enable())
+      if (s.enable())
       {
         if (!m_firstCol) m_t << "\n";
         m_t << ".PP\n";
@@ -188,64 +188,52 @@ void ManDocVisitor::visit(DocStyleChange *s)
       break;
     case DocStyleChange::Div:  /* HTML only */ break;
     case DocStyleChange::Span: /* HTML only */ break;
-    case DocStyleChange::Details: /* emulation of the <details> tag */
-      if (!s->enable())
-      {
-        if (!m_firstCol) m_t << "\n";
-        m_t << ".PP\n";
-        m_firstCol=TRUE;
-      }
-      break;
-    case DocStyleChange::Summary: /* emulation of the <summary> tag inside a <details> tag */
-      if (s->enable()) m_t << "\\fB";      else m_t << "\\fP";
-      m_firstCol=FALSE;
-      break;
   }
 }
 
-void ManDocVisitor::visit(DocVerbatim *s)
+void ManDocVisitor::operator()(const DocVerbatim &s)
 {
   if (m_hide) return;
   QCString lang = m_langExt;
-  if (!s->language().isEmpty()) // explicit language setting
+  if (!s.language().isEmpty()) // explicit language setting
   {
-    lang = s->language();
+    lang = s.language();
   }
   SrcLangExt langExt = getLanguageFromCodeLang(lang);
-  switch (s->type())
+  switch (s.type())
   {
     case DocVerbatim::Code:
       if (!m_firstCol) m_t << "\n";
       m_t << ".PP\n";
       m_t << ".nf\n";
-      getCodeParser(lang).parseCode(m_ci,s->context(),s->text(),
+      getCodeParser(lang).parseCode(m_ci,s.context(),s.text(),
                                         langExt,
-                                        s->isExample(),s->exampleFile());
+                                        s.isExample(),s.exampleFile());
       if (!m_firstCol) m_t << "\n";
       m_t << ".fi\n";
       m_t << ".PP\n";
       m_firstCol=TRUE;
       break;
     case DocVerbatim::JavaDocLiteral:
-      filter(s->text());
+      filter(s.text());
       break;
     case DocVerbatim::JavaDocCode:
       m_t << "\\fC\n";
-      filter(s->text());
+      filter(s.text());
       m_t << "\\fP\n";
       break;
     case DocVerbatim::Verbatim:
       if (!m_firstCol) m_t << "\n";
       m_t << ".PP\n";
       m_t << ".nf\n";
-      filter(s->text());
+      filter(s.text());
       if (!m_firstCol) m_t << "\n";
       m_t << ".fi\n";
       m_t << ".PP\n";
       m_firstCol=TRUE;
       break;
     case DocVerbatim::ManOnly:
-      m_t << s->text();
+      m_t << s.text();
       break;
     case DocVerbatim::HtmlOnly:
     case DocVerbatim::XmlOnly:
@@ -260,29 +248,29 @@ void ManDocVisitor::visit(DocVerbatim *s)
   }
 }
 
-void ManDocVisitor::visit(DocAnchor *)
+void ManDocVisitor::operator()(const DocAnchor &)
 {
   /* no support for anchors in man pages */
 }
 
-void ManDocVisitor::visit(DocInclude *inc)
+void ManDocVisitor::operator()(const DocInclude &inc)
 {
   if (m_hide) return;
-  SrcLangExt langExt = getLanguageFromFileName(inc->extension());
-  switch(inc->type())
+  SrcLangExt langExt = getLanguageFromFileName(inc.extension());
+  switch(inc.type())
   {
     case DocInclude::IncWithLines:
       {
          if (!m_firstCol) m_t << "\n";
          m_t << ".PP\n";
          m_t << ".nf\n";
-         FileInfo cfi( inc->file().str() );
+         FileInfo cfi( inc.file().str() );
          FileDef *fd = createFileDef( cfi.dirPath(), cfi.fileName() );
-         getCodeParser(inc->extension()).parseCode(m_ci,inc->context(),
-                                           inc->text(),
+         getCodeParser(inc.extension()).parseCode(m_ci,inc.context(),
+                                           inc.text(),
                                            langExt,
-                                           inc->isExample(),
-                                           inc->exampleFile(),
+                                           inc.isExample(),
+                                           inc.exampleFile(),
                                            fd,   // fileDef,
                                            -1,    // start line
                                            -1,    // end line
@@ -301,11 +289,11 @@ void ManDocVisitor::visit(DocInclude *inc)
       if (!m_firstCol) m_t << "\n";
       m_t << ".PP\n";
       m_t << ".nf\n";
-      getCodeParser(inc->extension()).parseCode(m_ci,inc->context(),
-                                        inc->text(),
+      getCodeParser(inc.extension()).parseCode(m_ci,inc.context(),
+                                        inc.text(),
                                         langExt,
-                                        inc->isExample(),
-                                        inc->exampleFile(),
+                                        inc.isExample(),
+                                        inc.exampleFile(),
                                         0,     // fileDef
                                         -1,    // startLine
                                         -1,    // endLine
@@ -327,13 +315,13 @@ void ManDocVisitor::visit(DocInclude *inc)
     case DocInclude::DocbookInclude:
       break;
     case DocInclude::ManInclude:
-      m_t << inc->text();
+      m_t << inc.text();
       break;
     case DocInclude::VerbInclude:
       if (!m_firstCol) m_t << "\n";
       m_t << ".PP\n";
       m_t << ".nf\n";
-      m_t << inc->text();
+      m_t << inc.text();
       if (!m_firstCol) m_t << "\n";
       m_t << ".fi\n";
       m_t << ".PP\n";
@@ -343,12 +331,12 @@ void ManDocVisitor::visit(DocInclude *inc)
       if (!m_firstCol) m_t << "\n";
       m_t << ".PP\n";
       m_t << ".nf\n";
-      getCodeParser(inc->extension()).parseCode(m_ci,
-                                        inc->context(),
-                                        extractBlock(inc->text(),inc->blockId()),
+      getCodeParser(inc.extension()).parseCode(m_ci,
+                                        inc.context(),
+                                        extractBlock(inc.text(),inc.blockId()),
                                         langExt,
-                                        inc->isExample(),
-                                        inc->exampleFile()
+                                        inc.isExample(),
+                                        inc.exampleFile()
                                        );
       if (!m_firstCol) m_t << "\n";
       m_t << ".fi\n";
@@ -360,16 +348,16 @@ void ManDocVisitor::visit(DocInclude *inc)
          if (!m_firstCol) m_t << "\n";
          m_t << ".PP\n";
          m_t << ".nf\n";
-         FileInfo cfi( inc->file().str() );
+         FileInfo cfi( inc.file().str() );
          FileDef *fd = createFileDef( cfi.dirPath(), cfi.fileName() );
-         getCodeParser(inc->extension()).parseCode(m_ci,
-                                           inc->context(),
-                                           extractBlock(inc->text(),inc->blockId()),
+         getCodeParser(inc.extension()).parseCode(m_ci,
+                                           inc.context(),
+                                           extractBlock(inc.text(),inc.blockId()),
                                            langExt,
-                                           inc->isExample(),
-                                           inc->exampleFile(),
+                                           inc.isExample(),
+                                           inc.exampleFile(),
                                            fd,
-                                           lineBlock(inc->text(),inc->blockId()),
+                                           lineBlock(inc.text(),inc.blockId()),
                                            -1,    // endLine
                                            FALSE, // inlineFragment
                                            0,     // memberDef
@@ -390,14 +378,14 @@ void ManDocVisitor::visit(DocInclude *inc)
   }
 }
 
-void ManDocVisitor::visit(DocIncOperator *op)
+void ManDocVisitor::operator()(const DocIncOperator &op)
 {
-  QCString locLangExt = getFileNameExtension(op->includeFileName());
+  QCString locLangExt = getFileNameExtension(op.includeFileName());
   if (locLangExt.isEmpty()) locLangExt = m_langExt;
   SrcLangExt langExt = getLanguageFromFileName(locLangExt);
   //printf("DocIncOperator: type=%d first=%d, last=%d text='%s'\n",
-  //    op->type(),op->isFirst(),op->isLast(),qPrint(op->text()));
-  if (op->isFirst())
+  //    op.type(),op.isFirst(),op.isLast(),qPrint(op.text()));
+  if (op.isFirst())
   {
     if (!m_hide)
     {
@@ -408,33 +396,33 @@ void ManDocVisitor::visit(DocIncOperator *op)
     pushHidden(m_hide);
     m_hide = TRUE;
   }
-  if (op->type()!=DocIncOperator::Skip)
+  if (op.type()!=DocIncOperator::Skip)
   {
     m_hide = popHidden();
     if (!m_hide)
     {
       FileDef *fd = 0;
-      if (!op->includeFileName().isEmpty())
+      if (!op.includeFileName().isEmpty())
       {
-        FileInfo cfi( op->includeFileName().str() );
+        FileInfo cfi( op.includeFileName().str() );
         fd = createFileDef( cfi.dirPath(), cfi.fileName() );
       }
 
-      getCodeParser(locLangExt).parseCode(m_ci,op->context(),op->text(),langExt,
-                                        op->isExample(),op->exampleFile(),
+      getCodeParser(locLangExt).parseCode(m_ci,op.context(),op.text(),langExt,
+                                        op.isExample(),op.exampleFile(),
                                         fd,     // fileDef
-                                        op->line(),    // startLine
+                                        op.line(),    // startLine
                                         -1,    // endLine
                                         FALSE, // inline fragment
                                         0,     // memberDef
-                                        op->showLineNo()  // show line numbers
+                                        op.showLineNo()  // show line numbers
                                        );
       if (fd) delete fd;
     }
     pushHidden(m_hide);
     m_hide=TRUE;
   }
-  if (op->isLast())
+  if (op.isLast())
   {
     m_hide = popHidden();
     if (!m_hide)
@@ -451,58 +439,61 @@ void ManDocVisitor::visit(DocIncOperator *op)
   }
 }
 
-void ManDocVisitor::visit(DocFormula *f)
+void ManDocVisitor::operator()(const DocFormula &f)
 {
   if (m_hide) return;
-  m_t << f->text();
+  m_t << f.text();
 }
 
-void ManDocVisitor::visit(DocIndexEntry *)
+void ManDocVisitor::operator()(const DocIndexEntry &)
 {
 }
 
-void ManDocVisitor::visit(DocSimpleSectSep *)
+void ManDocVisitor::operator()(const DocSimpleSectSep &)
 {
 }
 
-void ManDocVisitor::visit(DocCite *cite)
+void ManDocVisitor::operator()(const DocCite &cite)
 {
   if (m_hide) return;
   m_t << "\\fB";
-  if (cite->file().isEmpty()) m_t << "[";
-  filter(cite->text());
-  if (cite->file().isEmpty()) m_t << "]";
+  if (cite.file().isEmpty()) m_t << "[";
+  filter(cite.text());
+  if (cite.file().isEmpty()) m_t << "]";
   m_t << "\\fP";
 }
 
+void ManDocVisitor::operator()(const DocSeparator &s)
+{
+  if (m_hide) return;
+  m_t << s.chars();
+}
+
 
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
 
-void ManDocVisitor::visitPre(DocAutoList *)
+void ManDocVisitor::operator()(const DocAutoList &l)
 {
   if (m_hide) return;
   m_indent+=2;
-}
-
-void ManDocVisitor::visitPost(DocAutoList *)
-{
-  if (m_hide) return;
+  visitChildren(l);
   m_indent-=2;
   m_t << ".PP\n";
 }
 
-void ManDocVisitor::visitPre(DocAutoListItem *li)
+void ManDocVisitor::operator()(const DocAutoListItem &li)
 {
   if (m_hide) return;
   QCString ws;
   ws.fill(' ',m_indent-2);
   if (!m_firstCol) m_t << "\n";
   m_t << ".IP \"" << ws;
-  if (((DocAutoList *)li->parent())->isEnumList())
+  const DocAutoList *list = std::get_if<DocAutoList>(li.parent());
+  if (list && list->isEnumList())
   {
-    m_t << li->itemNumber() << ".\" " << m_indent+2;
+    m_t << li.itemNumber() << ".\" " << m_indent+2;
   }
   else // bullet list
   {
@@ -510,25 +501,18 @@ void ManDocVisitor::visitPre(DocAutoListItem *li)
   }
   m_t << "\n";
   m_firstCol=TRUE;
-}
-
-void ManDocVisitor::visitPost(DocAutoListItem *)
-{
-  if (m_hide) return;
+  visitChildren(li);
   m_t << "\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocPara *)
-{
-}
-
-void ManDocVisitor::visitPost(DocPara *p)
+void ManDocVisitor::operator()(const DocPara &p)
 {
   if (m_hide) return;
-  if (!p->isLast() &&            // omit <p> for last paragraph
-      !(p->parent() &&           // and for parameter sections
-        p->parent()->kind()==DocNode::Kind_ParamSect
+  visitChildren(p);
+  if (!p.isLast() &&            // omit <p> for last paragraph
+      !(p.parent() &&           // and for parameter sections
+        std::get_if<DocParamSect>(p.parent())
        )
      )
   {
@@ -538,15 +522,12 @@ void ManDocVisitor::visitPost(DocPara *p)
   }
 }
 
-void ManDocVisitor::visitPre(DocRoot *)
+void ManDocVisitor::operator()(const DocRoot &r)
 {
+  visitChildren(r);
 }
 
-void ManDocVisitor::visitPost(DocRoot *)
-{
-}
-
-void ManDocVisitor::visitPre(DocSimpleSect *s)
+void ManDocVisitor::operator()(const DocSimpleSect &s)
 {
   if (m_hide) return;
   if (!m_firstCol)
@@ -555,7 +536,7 @@ void ManDocVisitor::visitPre(DocSimpleSect *s)
     m_t << ".PP\n";
   }
   m_t << "\\fB";
-  switch(s->type())
+  switch(s.type())
   {
     case DocSimpleSect::See:
       m_t << theTranslator->trSeeAlso(); break;
@@ -593,49 +574,37 @@ void ManDocVisitor::visitPre(DocSimpleSect *s)
   }
 
   // special case 1: user defined title
-  if (s->type()!=DocSimpleSect::User && s->type()!=DocSimpleSect::Rcs)
+  if (s.title())
   {
-    m_t << "\\fP\n";
-    m_t << ".RS 4\n";
+    std::visit(*this,*s.title());
   }
-}
-
-void ManDocVisitor::visitPost(DocSimpleSect *)
-{
-  if (m_hide) return;
+  m_t << "\\fP\n";
+  m_t << ".RS 4\n";
+  visitChildren(s);
   if (!m_firstCol) m_t << "\n";
   m_t << ".RE\n";
   m_t << ".PP\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocTitle *)
-{
-}
-
-void ManDocVisitor::visitPost(DocTitle *)
+void ManDocVisitor::operator()(const DocTitle &t)
 {
   if (m_hide) return;
-  m_t << "\\fP\n";
-  m_t << ".RS 4\n";
+  visitChildren(t);
 }
 
-void ManDocVisitor::visitPre(DocSimpleList *)
+void ManDocVisitor::operator()(const DocSimpleList &l)
 {
   if (m_hide) return;
   m_indent+=2;
   if (!m_firstCol) m_t << "\n";
   m_t << ".PD 0\n";
-}
-
-void ManDocVisitor::visitPost(DocSimpleList *)
-{
-  if (m_hide) return;
+  visitChildren(l);
   m_indent-=2;
   m_t << ".PP\n";
 }
 
-void ManDocVisitor::visitPre(DocSimpleListItem *)
+void ManDocVisitor::operator()(const DocSimpleListItem &li)
 {
   if (m_hide) return;
   QCString ws;
@@ -643,32 +612,28 @@ void ManDocVisitor::visitPre(DocSimpleListItem *)
   if (!m_firstCol) m_t << "\n";
   m_t << ".IP \"" << ws << "\\(bu\" " << m_indent << "\n";
   m_firstCol=TRUE;
-}
-
-void ManDocVisitor::visitPost(DocSimpleListItem *)
-{
-  if (m_hide) return;
+  if (li.paragraph())
+  {
+    visit(*this,*li.paragraph());
+  }
   m_t << "\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocSection *s)
+void ManDocVisitor::operator()(const DocSection &s)
 {
   if (m_hide) return;
   if (!m_firstCol) m_t << "\n";
-  if (s->level()==1) m_t << ".SH"; else m_t << ".SS";
+  if (s.level()==1) m_t << ".SH"; else m_t << ".SS";
   m_t << " \"";
-  filter(s->title());
+  filter(s.title());
   m_t << "\"\n";
-  if (s->level()==1) m_t << ".PP\n";
+  if (s.level()==1) m_t << ".PP\n";
   m_firstCol=TRUE;
+  visitChildren(s);
 }
 
-void ManDocVisitor::visitPost(DocSection *)
-{
-}
-
-void ManDocVisitor::visitPre(DocHtmlList *l)
+void ManDocVisitor::operator()(const DocHtmlList &l)
 {
   if (m_hide) return;
   m_indent+=2;
@@ -676,7 +641,7 @@ void ManDocVisitor::visitPre(DocHtmlList *l)
   m_t << ".PD 0\n";
   man_listItemInfo[m_indent].number = 1;
   man_listItemInfo[m_indent].type   = '1';
-  for (const auto &opt : l->attribs())
+  for (const auto &opt : l.attribs())
   {
     if (opt.name=="type")
     {
@@ -689,26 +654,23 @@ void ManDocVisitor::visitPre(DocHtmlList *l)
       if (ok) man_listItemInfo[m_indent].number = val;
     }
   }
-}
-
-void ManDocVisitor::visitPost(DocHtmlList *)
-{
-  if (m_hide) return;
+  visitChildren(l);
   m_indent-=2;
   if (!m_firstCol) m_t << "\n";
   m_t << ".PP\n";
 }
 
-void ManDocVisitor::visitPre(DocHtmlListItem *li)
+void ManDocVisitor::operator()(const DocHtmlListItem &li)
 {
   if (m_hide) return;
   QCString ws;
   ws.fill(' ',m_indent-2);
   if (!m_firstCol) m_t << "\n";
   m_t << ".IP \"" << ws;
-  if (((DocHtmlList *)li->parent())->type()==DocHtmlList::Ordered)
+  const DocHtmlList *list = std::get_if<DocHtmlList>(li.parent());
+  if (list && list->type()==DocHtmlList::Ordered)
   {
-    for (const auto &opt : li->attribs())
+    for (const auto &opt : li.attribs())
     {
       if (opt.name=="value")
       {
@@ -747,202 +709,147 @@ void ManDocVisitor::visitPre(DocHtmlListItem *li)
   }
   m_t << "\n";
   m_firstCol=TRUE;
-}
-
-void ManDocVisitor::visitPost(DocHtmlListItem *)
-{
-  if (m_hide) return;
+  visitChildren(li);
   m_t << "\n";
   m_firstCol=TRUE;
 }
 
-//void ManDocVisitor::visitPre(DocHtmlPre *)
-//{
-//  if (!m_firstCol) m_t << "\n";
-//  m_t << ".PP\n";
-//  m_t << ".nf\n";
-//  m_insidePre=TRUE;
-//}
-//
-//void ManDocVisitor::visitPost(DocHtmlPre *)
-//{
-//  m_insidePre=FALSE;
-//  if (!m_firstCol) m_t << "\n";
-//  m_t << ".fi\n";
-//  m_t << ".PP\n";
-//  m_firstCol=TRUE;
-//}
-
-void ManDocVisitor::visitPre(DocHtmlDescList *)
-{
-}
-
-void ManDocVisitor::visitPost(DocHtmlDescList *)
+void ManDocVisitor::operator()(const DocHtmlDescList &dl)
 {
   if (m_hide) return;
+  visitChildren(dl);
   if (!m_firstCol) m_t << "\n";
   m_t << ".PP\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocHtmlDescTitle *)
+void ManDocVisitor::operator()(const DocHtmlDescTitle &dt)
 {
   if (m_hide) return;
   if (!m_firstCol) m_t << "\n";
   m_t << ".IP \"\\fB";
   m_firstCol=FALSE;
-}
-
-void ManDocVisitor::visitPost(DocHtmlDescTitle *)
-{
-  if (m_hide) return;
+  visitChildren(dt);
   m_t << "\\fP\" 1c\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocHtmlDescData *)
+void ManDocVisitor::operator()(const DocHtmlDescData &dd)
 {
+  visitChildren(dd);
 }
 
-void ManDocVisitor::visitPost(DocHtmlDescData *)
+void ManDocVisitor::operator()(const DocHtmlTable &t)
 {
+  visitChildren(t);
 }
 
-void ManDocVisitor::visitPre(DocHtmlTable *)
+void ManDocVisitor::operator()(const DocHtmlCaption &c)
 {
+  visitChildren(c);
 }
 
-void ManDocVisitor::visitPost(DocHtmlTable *)
+void ManDocVisitor::operator()(const DocHtmlRow &r)
 {
+  visitChildren(r);
 }
 
-void ManDocVisitor::visitPre(DocHtmlCaption *)
+void ManDocVisitor::operator()(const DocHtmlCell &c)
 {
+  visitChildren(c);
 }
 
-void ManDocVisitor::visitPost(DocHtmlCaption *)
+void ManDocVisitor::operator()(const DocInternal &i)
 {
+  visitChildren(i);
 }
 
-void ManDocVisitor::visitPre(DocHtmlRow *)
-{
-}
-
-void ManDocVisitor::visitPost(DocHtmlRow *)
-{
-}
-
-void ManDocVisitor::visitPre(DocHtmlCell *)
-{
-}
-
-void ManDocVisitor::visitPost(DocHtmlCell *)
-{
-}
-
-void ManDocVisitor::visitPre(DocInternal *)
-{
-  if (m_hide) return;
-  //if (!m_firstCol) m_t << "\n";
-  //m_t << ".PP\n";
-  //m_t << "\\fB" << theTranslator->trForInternalUseOnly() << "\\fP\n";
-  //m_t << ".RS 4\n";
-}
-
-void ManDocVisitor::visitPost(DocInternal *)
-{
-  if (m_hide) return;
-  //if (!m_firstCol) m_t << "\n";
-  //m_t << ".RE\n";
-  //m_t << ".PP\n";
-  //m_firstCol=TRUE;
-}
-
-void ManDocVisitor::visitPre(DocHRef *)
+void ManDocVisitor::operator()(const DocHRef &href)
 {
   if (m_hide) return;
   m_t << "\\fC";
-}
-
-void ManDocVisitor::visitPost(DocHRef *)
-{
-  if (m_hide) return;
+  visitChildren(href);
   m_t << "\\fP";
 }
 
-void ManDocVisitor::visitPre(DocHtmlHeader *header)
+void ManDocVisitor::operator()(const DocHtmlSummary &s)
 {
-  if (m_hide) return;
-  if (!m_firstCol) m_t << "\n";
-  if (header->level()==1) m_t << ".SH"; else m_t << ".SS";
-  m_t << " \"";
+  m_t << "\\fB";
+  visitChildren(s);
+  m_t << "\\fP\n.PP\n";
 }
 
-void ManDocVisitor::visitPost(DocHtmlHeader *header)
+void ManDocVisitor::operator()(const DocHtmlDetails &d)
 {
   if (m_hide) return;
-  m_t << "\"\n";
-  if (header->level()==1) m_t << ".PP\n";
+  if (!m_firstCol)
+  {
+    m_t << "\n";
+    m_t << ".PP\n";
+  }
+  auto summary = d.summary();
+  if (summary)
+  {
+    std::visit(*this,*summary);
+    m_t << ".PP\n";
+    m_t << ".RS 4\n";
+  }
+  visitChildren(d);
+  if (!m_firstCol) m_t << "\n";
+  if (summary)
+  {
+    m_t << ".RE\n";
+  }
+  m_t << ".PP\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocImage *)
+void ManDocVisitor::operator()(const DocHtmlHeader &header)
+{
+  if (m_hide) return;
+  if (!m_firstCol) m_t << "\n";
+  if (header.level()==1) m_t << ".SH"; else m_t << ".SS";
+  m_t << " \"";
+  visitChildren(header);
+  m_t << "\"\n";
+  if (header.level()==1) m_t << ".PP\n";
+  m_firstCol=TRUE;
+}
+
+void ManDocVisitor::operator()(const DocImage &)
 {
 }
 
-void ManDocVisitor::visitPost(DocImage *)
+void ManDocVisitor::operator()(const DocDotFile &f)
 {
 }
 
-void ManDocVisitor::visitPre(DocDotFile *)
+void ManDocVisitor::operator()(const DocMscFile &)
 {
 }
 
-void ManDocVisitor::visitPost(DocDotFile *)
-{
-}
-void ManDocVisitor::visitPre(DocMscFile *)
+void ManDocVisitor::operator()(const DocDiaFile &)
 {
 }
 
-void ManDocVisitor::visitPost(DocMscFile *)
-{
-}
-
-void ManDocVisitor::visitPre(DocDiaFile *)
-{
-}
-
-void ManDocVisitor::visitPost(DocDiaFile *)
-{
-}
-
-void ManDocVisitor::visitPre(DocLink *)
+void ManDocVisitor::operator()(const DocLink &dl)
 {
   if (m_hide) return;
   m_t << "\\fB";
-}
-
-void ManDocVisitor::visitPost(DocLink *)
-{
-  if (m_hide) return;
+  visitChildren(dl);
   m_t << "\\fP";
 }
 
-void ManDocVisitor::visitPre(DocRef *ref)
+void ManDocVisitor::operator()(const DocRef &ref)
 {
   if (m_hide) return;
   m_t << "\\fB";
-  if (!ref->hasLinkText()) filter(ref->targetTitle());
-}
-
-void ManDocVisitor::visitPost(DocRef *)
-{
-  if (m_hide) return;
+  if (!ref.hasLinkText()) filter(ref.targetTitle());
+  visitChildren(ref);
   m_t << "\\fP";
 }
 
-void ManDocVisitor::visitPre(DocSecRefItem *)
+void ManDocVisitor::operator()(const DocSecRefItem &ref)
 {
   if (m_hide) return;
   QCString ws;
@@ -950,30 +857,22 @@ void ManDocVisitor::visitPre(DocSecRefItem *)
   if (!m_firstCol) m_t << "\n";
   m_t << ".IP \"" << ws << "\\(bu\" " << m_indent << "\n";
   m_firstCol=TRUE;
-}
-
-void ManDocVisitor::visitPost(DocSecRefItem *)
-{
-  if (m_hide) return;
+  visitChildren(ref);
   m_t << "\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocSecRefList *)
+void ManDocVisitor::operator()(const DocSecRefList &l)
 {
   if (m_hide) return;
   m_indent+=2;
-}
-
-void ManDocVisitor::visitPost(DocSecRefList *)
-{
-  if (m_hide) return;
+  visitChildren(l);
   m_indent-=2;
   if (!m_firstCol) m_t << "\n";
   m_t << ".PP\n";
 }
 
-void ManDocVisitor::visitPre(DocParamSect *s)
+void ManDocVisitor::operator()(const DocParamSect &s)
 {
   if (m_hide) return;
   if (!m_firstCol)
@@ -982,7 +881,7 @@ void ManDocVisitor::visitPre(DocParamSect *s)
     m_t << ".PP\n";
   }
   m_t << "\\fB";
-  switch(s->type())
+  switch(s.type())
   {
     case DocParamSect::Param:
       m_t << theTranslator->trParameters(); break;
@@ -997,93 +896,70 @@ void ManDocVisitor::visitPre(DocParamSect *s)
   }
   m_t << "\\fP\n";
   m_t << ".RS 4\n";
-}
-
-void ManDocVisitor::visitPost(DocParamSect *)
-{
-  if (m_hide) return;
+  visitChildren(s);
   if (!m_firstCol) m_t << "\n";
   m_t << ".RE\n";
   m_t << ".PP\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocParamList *pl)
+void ManDocVisitor::operator()(const DocParamList &pl)
 {
   if (m_hide) return;
   m_t << "\\fI";
   bool first=TRUE;
-  for (const auto &param : pl->parameters())
+  for (const auto &param : pl.parameters())
   {
     if (!first) m_t << ","; else first=FALSE;
-    if (param->kind()==DocNode::Kind_Word)
-    {
-      visit((DocWord*)param.get());
-    }
-    else if (param->kind()==DocNode::Kind_LinkedWord)
-    {
-      visit((DocLinkedWord*)param.get());
-    }
+    std::visit(*this,param);
   }
   m_t << "\\fP ";
-}
-
-void ManDocVisitor::visitPost(DocParamList *pl)
-{
-  if (m_hide) return;
-  if (!pl->isLast())
+  for (const auto &par : pl.paragraphs())
+  {
+    std::visit(*this,par);
+  }
+  if (!pl.isLast())
   {
     if (!m_firstCol) m_t << "\n";
     m_t << ".br\n";
   }
 }
 
-void ManDocVisitor::visitPre(DocXRefItem *x)
+void ManDocVisitor::operator()(const DocXRefItem &x)
 {
   if (m_hide) return;
-  if (x->title().isEmpty()) return;
+  if (x.title().isEmpty()) return;
   if (!m_firstCol)
   {
     m_t << "\n";
     m_t << ".PP\n";
   }
   m_t << "\\fB";
-  filter(x->title());
+  filter(x.title());
   m_t << "\\fP\n";
   m_t << ".RS 4\n";
-}
-
-void ManDocVisitor::visitPost(DocXRefItem *x)
-{
-  if (m_hide) return;
-  if (x->title().isEmpty()) return;
+  visitChildren(x);
+  if (x.title().isEmpty()) return;
   if (!m_firstCol) m_t << "\n";
   m_t << ".RE\n";
   m_t << ".PP\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocInternalRef *)
+void ManDocVisitor::operator()(const DocInternalRef &ref)
 {
   if (m_hide) return;
   m_t << "\\fB";
-}
-
-void ManDocVisitor::visitPost(DocInternalRef *)
-{
-  if (m_hide) return;
+  visitChildren(ref);
   m_t << "\\fP";
 }
 
-void ManDocVisitor::visitPre(DocText *)
+void ManDocVisitor::operator()(const DocText &t)
 {
+  visitChildren(t);
 }
 
-void ManDocVisitor::visitPost(DocText *)
-{
-}
-
-void ManDocVisitor::visitPre(DocHtmlBlockQuote *)
+void ManDocVisitor::operator()(const DocHtmlBlockQuote &q)
 {
   if (m_hide) return;
   if (!m_firstCol)
@@ -1092,34 +968,22 @@ void ManDocVisitor::visitPre(DocHtmlBlockQuote *)
     m_t << ".PP\n";
   }
   m_t << ".RS 4\n"; // TODO: add support for nested block quotes
-}
-
-void ManDocVisitor::visitPost(DocHtmlBlockQuote *)
-{
-  if (m_hide) return;
+  visitChildren(q);
   if (!m_firstCol) m_t << "\n";
   m_t << ".RE\n";
   m_t << ".PP\n";
   m_firstCol=TRUE;
 }
 
-void ManDocVisitor::visitPre(DocVhdlFlow *)
+void ManDocVisitor::operator()(const DocVhdlFlow &)
 {
 }
 
-void ManDocVisitor::visitPost(DocVhdlFlow *)
+void ManDocVisitor::operator()(const DocParBlock &pb)
 {
+  visitChildren(pb);
 }
 
-void ManDocVisitor::visitPre(DocParBlock *)
-{
-}
-
-void ManDocVisitor::visitPost(DocParBlock *)
-{
-}
-
-
 void ManDocVisitor::filter(const QCString &str)
 {
   if (!str.isEmpty())
