@@ -32,10 +32,6 @@
 
 class TranslatorArabic : public TranslatorAdapter_1_4_6
 {
-  protected:
-    friend class TranslatorAdapterBase;
-    virtual ~TranslatorArabic() {}
-
   public:
 
     // --- Language control methods -------------------
@@ -70,6 +66,10 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     virtual QCString trISOLang()
     { return "ar-EG"; }
+    virtual QCString getLanguageString()
+    {
+      return "0xC01 Arabic (Egypt)";
+    }
 
     // --- Language translation methods -------------------
 
@@ -85,6 +85,10 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     virtual QCString trDetailedDescription()
     { return "وصف تفصيلي"; }
 
+    /*! header that is used when the summary tag is missing inside the details tag */
+    virtual QCString trDetails()
+    { return "التفاصيل"; }
+
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return "توثيق تعريفات النوع الأعضاء"; }
@@ -135,7 +139,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="تم تكوينها آليا بواسطة Doxygen";
-      if (!s.isEmpty()) result+=(QCString)" لـ "+s;
+      if (!s.isEmpty()) result+=" لـ "+s;
       result+=" من ملفات المصدر.";
       return result;
     }
@@ -181,10 +185,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     virtual QCString trFileList()
     { return "قائمة الملفات"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "الملفات الرأسية"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
@@ -318,10 +318,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return "Here are the header files that make up the API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "هذه قائمة بكل الأمثلة:"; }
@@ -334,14 +330,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     virtual QCString trModulesDescription()
     { return "هذه قائمة بكل المكونات:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "لا يوجد وصف متاح"; }
-
-    // index titles (the project name is prepended for these)
-
 
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
@@ -395,6 +383,10 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
       {
         return "فهرس هيكل البيانات";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "فهرس الفئة";
@@ -413,12 +405,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     virtual QCString trExampleDocumentation()
     { return "توثيق الأمثلة"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "توثيق الصفحات"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "الكتيب المرجعي"; }
@@ -515,34 +501,22 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Generated on "+date;
-      if (!projName.isEmpty()) result+=(QCString)" for "+projName;
-      result+=(QCString)" by";
+      QCString result="Generated on "+date;
+      if (!projName.isEmpty()) result+=" for "+projName;
+      result+=" by";
       return result;
     }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Inheritance diagram for "+clName+":";
+      return "Inheritance diagram for "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "للاستخدام الداخلي فقط."; }
-
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "Reimplemented for internal reasons; the API is not affected."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "تنبيه"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "Bugs and limitations"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return "إصدارة"; }
@@ -613,7 +587,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Class"; break;
@@ -773,7 +747,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"توثيق   ";
+      QCString result="توثيق   ";
       switch(compType)
       {
         case ClassDef::Class:      result+="هذه الفئة"; break;
@@ -813,10 +787,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "مصادر";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "Definition at line @0 of file @1.";
@@ -842,12 +812,12 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"رسم التعاون لـ "+clName+":";
+      return "رسم التعاون لـ "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"رسم اعتمادية التضمين لـ "+fName+":";
+      return "رسم اعتمادية التضمين لـ "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1133,12 +1103,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"حزمة "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "قائمة الحزم";
+      return "حزمة "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1150,11 +1115,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     {
       return "حزم";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "توثيق الحزم";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1291,17 +1251,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
       return result;
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool /*first_capital*/, bool singular)
-    {
-      QCString result("حقل");
-      if (!singular)  result="حقول";
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1411,14 +1360,18 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "دوال الحزمة";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "أعضاء الحزمة";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "دوال ساكنة للحزمة";
     }
@@ -1530,14 +1483,6 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     virtual QCString trDirectories()
     { return "الأدلة"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "هذا الشكل الهرمي للأدلة تم ترتيبه أبجديا بصورة تقريبية، "
-	"وليس ترتيبا أبجديا كاملا:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1568,6 +1513,23 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
               "فقط في نوعية ال argument(s) التي تقبلها.";
     }
 
+    virtual QCString trDayOfWeek(int dayOfWeek, bool, bool full)
+    {
+      static const char *days_short[]   = { "الإثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت", "الأحد" };
+      static const char *days_full[]    = { "الإثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت", "الأحد" };
+      return full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+    }
+    virtual QCString trMonth(int month, bool, bool full)
+    {
+      static const char *months_short[] = { "يناير", "فبراير", "مارس", "أبريل", "مايو", "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" };
+      static const char *months_full[]  = { "يناير", "فبراير", "مارس", "أبريل", "مايو", "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر" };
+      return full? months_full[month-1] : months_short[month-1];
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "ص", "م" };
+      return dayPeriod[period];
+    }
 };
 
 #endif
