@@ -48,7 +48,7 @@
 #ifndef TRANSLATOR_GR_H
 #define TRANSLATOR_GR_H
 
-class TranslatorGreek : public Translator
+class TranslatorGreek : public TranslatorAdapter_1_9_4
 {
   public:
 
@@ -98,6 +98,10 @@ class TranslatorGreek : public Translator
     virtual QCString trDetailedDescription()
     { return "Λεπτομερής Περιγραφή"; }
 
+    /*! header that is used when the summary tag is missing inside the details tag */
+    virtual QCString trDetails()
+    { return "Λεπτομέρειες"; }
+
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return "Τεκμηρίωση Μελών Ορισμών Τύπων"; }
@@ -148,7 +152,7 @@ class TranslatorGreek : public Translator
      */
     virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Δημιουργήθηκε αυτόματα από το Doxygen";
-      if (!s.isEmpty()) result+=(QCString)" για "+s;
+      if (!s.isEmpty()) result+=" για "+s;
       result+=" από τον πηγαίο κώδικα.";
       return result;
     }
@@ -395,6 +399,10 @@ class TranslatorGreek : public Translator
       {
         return "Τεκμηρίωση Δομών Δεδομένων";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Τεκμηρίωση Κλάσεων";
@@ -413,12 +421,6 @@ class TranslatorGreek : public Translator
     virtual QCString trExampleDocumentation()
     { return "Τεκμηρίωση Παραδειγμάτων"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Τεκμηρίωση Σελίδων"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Εγχειρίδιο Τεκμηρίωσης"; }
@@ -509,22 +511,18 @@ class TranslatorGreek : public Translator
      */
     virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Δημιουργήθηκε στις "+date;
-      if (!projName.isEmpty()) result+=(QCString)" για "+projName;
-      result+=(QCString)" από";
+      QCString result="Δημιουργήθηκε στις "+date;
+      if (!projName.isEmpty()) result+=" για "+projName;
+      result+=" από";
       return result;
     }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Διάγραμμα κληρονομικότητας για την "+clName+":";
+      return "Διάγραμμα κληρονομικότητας για την "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Μόνο για εσωτερική χρήση."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Προειδοποίηση"; }
@@ -599,7 +597,7 @@ class TranslatorGreek : public Translator
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)"Τεκμηρίωση";
+      QCString result="Τεκμηρίωση";
       if (isTemplate) result+=" Προτύπου";
       switch(compType)
       {
@@ -759,7 +757,7 @@ class TranslatorGreek : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για ";
+      QCString result="Η τεκμηρίωση για ";
       switch(compType)
       {
         case ClassDef::Class:      result+="αυτή την κλάση"; break;
@@ -824,12 +822,12 @@ class TranslatorGreek : public Translator
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Διάγραμμα Συνεργασίας για την κλάση "+clName+":";
+      return "Διάγραμμα Συνεργασίας για την κλάση "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Διάγραμμα εξάρτησης αρχείου συμπερίληψης για το "+fName+":";
+      return "Διάγραμμα εξάρτησης αρχείου συμπερίληψης για το "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1112,12 +1110,7 @@ class TranslatorGreek : public Translator
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Πακέτο "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Λίστα Πακέτων";
+      return "Πακέτο "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1207,6 +1200,10 @@ class TranslatorGreek : public Translator
     {
       return "Ευρετήριο";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x408 Greece";
+    }
 
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
@@ -1384,14 +1381,18 @@ class TranslatorGreek : public Translator
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Συναρτήσεις Πακέτου";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Μέλη Πακέτου";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Στατικές Συναρτήσεις Πακέτου";
     }
@@ -1503,14 +1504,6 @@ class TranslatorGreek : public Translator
     virtual QCString trDirectories()
     { return "Κατάλογοι"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    {
-			return "Η ιεραρχία καταλόγων ταξινομήθηκε αλφαβητικά, αλλά όχι πολύ αυστηρά:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1646,7 +1639,7 @@ class TranslatorGreek : public Translator
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Υπομονάδα"; break;
@@ -1714,7 +1707,7 @@ class TranslatorGreek : public Translator
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για ";
+      QCString result="Η τεκμηρίωση για ";
       switch(compType)
       {
         case ClassDef::Class:      result+="αυτή την υπομονάδα"; break;
@@ -1802,7 +1795,7 @@ class TranslatorGreek : public Translator
      */
     virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Αρχείο σε "+name;
+      return "Αρχείο σε "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
@@ -1811,7 +1804,7 @@ class TranslatorGreek : public Translator
      */
     virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Εσωκλείει το αρχείο στο "+name;
+      return "Εσωκλείει το αρχείο στο "+name;
     }
 
     /** Compiles a date string.
@@ -1826,20 +1819,43 @@ class TranslatorGreek : public Translator
      */
     virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
                                 int hour,int minutes,int seconds,
-                                bool includeTime)
+                                DateTimeType includeTime)
     {
       static const char *days[]   = { "Δευ","Τρι","Τετ","Πεμ","Παρ","Σαβ","Κυρ" };
       static const char *months[] = { "Ιαν","Φεβ","Μαρ","Απρ","Μαι","Ιουν","Ιουλ","Αυγ","Σεπ","Οκτ","Νοε","Δεκ" };
       QCString sdate;
-      sdate.sprintf("%s %.2d %s %d",days[dayOfWeek-1],day,months[month-1],year);
-      if (includeTime)
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Date)
+      {
+        sdate.sprintf("%s %.2d %s %d",days[dayOfWeek-1],day,months[month-1],year);
+      }
+      if (includeTime == DateTimeType::DateTime) sdate += " ";
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Time)
       {
         QCString stime;
-        stime.sprintf(" %.2d:%.2d:%.2d",hour,minutes,seconds);
+        stime.sprintf("%.2d:%.2d:%.2d",hour,minutes,seconds);
         sdate+=stime;
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool, bool full)
+    {
+      static const char *days_short[]   = { "Δευ", "Τρι", "Τετ", "Πεμ", "Παρ", "Σαβ", "Κυρ" };
+      static const char *days_full[]    = { "Δευτέρα", "Τρίτη", "Τετάρτη", "Πέμπτη", "Παρασκευή", "Σάββατο", "Κυριακή" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      return text;
+    }
+    virtual QCString trMonth(int month, bool, bool full)
+    {
+      static const char *months_short[] = { "Ιαν", "Φεβ", "Μαρ", "Απρ", "Μαϊ", "Ιουν", "Ιουλ", "Αυγ", "Σεπ", "Οκτ", "Νοε", "Δεκ" };
+      static const char *months_full[]  = { "Ιανουάριος", "Φεβρουάριος", "Μάρτιος", "Απρίλιος", "Μάιος", "Ιούνιος", "Ιούλιος", "Αύγουστος", "Σεπτέμβριος", "Οκτώβριος", "Νοέμβριος", "Δεκέμβριος" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "π.μ.", "μ.μ." };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1977,14 +1993,14 @@ class TranslatorGreek : public Translator
     /** UNO IDL service page title */
     virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Τεκμηρίωση Υπηρεσίας";
       return result;
     }
     /** UNO IDL singleton page title */
     virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Τεκμηρίωση Μονοσύνολου";
       return result;
     }
@@ -1992,7 +2008,7 @@ class TranslatorGreek : public Translator
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για την υπηρεσία αυτή "
+      QCString result="Η τεκμηρίωση για την υπηρεσία αυτή "
                                 "δημιουργήθηκε από ";
       if (single) result+="το ακόλουθο αρχείο:"; else result+="τα ακόλουθα αρχεία:";
       return result;
@@ -2001,7 +2017,7 @@ class TranslatorGreek : public Translator
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για αυτό το μονοσύνολο "
+      QCString result="Η τεκμηρίωση για αυτό το μονοσύνολο "
                                 "δημιουργήθηκε από ";
       if (single) result+="το ακόλουθο αρχείο:"; else result+="τα ακόλουθα αρχεία:";
       return result;
