@@ -35,7 +35,7 @@
  files frees the maintainer from thinking about whether the
  first, the second, or both files should be included or not, and
  why.  This holds namely for localized translators because their
- base class is changed occasionaly to adapter classes when the
+ base class is changed occasionally to adapter classes when the
  Translator class changes the interface, or back to the
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
@@ -84,6 +84,10 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     {
       return "lv";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x426 Latvian";
+    }
 
     // --- Language translation methods -------------------
 
@@ -99,6 +103,10 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trDetailedDescription()
     { return "Detalizēts apraksts"; }
 
+    /*! header that is used when the summary tag is missing inside the details tag */
+    virtual QCString trDetails()
+    { return "Sīkāka informācija"; }
+
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return "Elementa Typedef dokumentācija"; }
@@ -149,7 +157,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Automātiski ģenerēts izmantojot Doxygen";
-      if (!s.isEmpty()) result+=(QCString)" priekš "+s;
+      if (!s.isEmpty()) result+=" priekš "+s;
       result+=" no pirmkoda.";
       return result;
     }
@@ -397,6 +405,10 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       {
         return "Datu struktūras dokomentācija";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Klases dokumentācija";
@@ -415,12 +427,6 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trExampleDocumentation()
     { return "Piemēri"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Lapas dokumentācija"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Rokasgrāmata"; }
@@ -511,22 +517,18 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Ģenerēts "+date;
-      if (!projName.isEmpty()) result+=(QCString)" projektam "+projName;
-      result+=(QCString)" ar";
+      QCString result="Ģenerēts "+date;
+      if (!projName.isEmpty()) result+=" projektam "+projName;
+      result+=" ar";
       return result;
     }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Mantojamības diagramma klasei "+clName+":";
+      return "Mantojamības diagramma klasei "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Tikai iekšējai lietošanai."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Brīdinājums"; }
@@ -601,7 +603,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" klases"; break;
@@ -760,7 +762,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
         bool single)
     { // single is true implies a single file
-      QCString result=(QCString)"Šī";
+      QCString result="Šī";
       switch(compType)
       {
         case ClassDef::Class:      result+="s klases"; break;
@@ -825,12 +827,12 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Sadarbības diagramma klasei "+clName+":";
+      return "Sadarbības diagramma klasei "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Include dependency graph for "+fName+":";
+      return "Include dependency graph for "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1113,12 +1115,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Pakotne "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Pakotņu saraksts";
+      return "Pakotne "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1375,14 +1372,18 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Pakas funkcijas";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Pakas elementi";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statiskās pakas funkcijas";
     }
@@ -1494,14 +1495,6 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trDirectories()
     { return "Direktorijas"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Šī direktoriju hierarhija ir aptuveni, "
-             "bet ne pilnībā, alfabēta secībā:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1637,7 +1630,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" moduļa"; break;
@@ -1706,7 +1699,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentācija š";
+      QCString result="Dokumentācija š";
       switch(compType)
       {
         case ClassDef::Class:      result+="im modulim"; break;
@@ -1795,7 +1788,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"File in "+name;
+      return "File in "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
@@ -1804,7 +1797,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Includes file in "+name;
+      return "Includes file in "+name;
     }
 
     /** Compiles a date string.
@@ -1819,20 +1812,45 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
                                 int hour,int minutes,int seconds,
-                                bool includeTime)
+                                DateTimeType includeTime)
     {
       static const char *days[]   = { "Pirm","Otr","Tr","Cet","Piekt","Sest","Sv" };
       static const char *months[] = { "Jan","Feb","Mar","Apr","Mai","Jūn","Jūl","Aug","Sept","Okt","Nov","Dec" };
       QCString sdate;
-      sdate.sprintf("%s %s %d %d",days[dayOfWeek-1],months[month-1],day,year);
-      if (includeTime)
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Date)
+      {
+        sdate.sprintf("%s %s %d %d",days[dayOfWeek-1],months[month-1],day,year);
+      }
+      if (includeTime == DateTimeType::DateTime) sdate += " ";
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Time)
       {
         QCString stime;
-        stime.sprintf(" %.2d:%.2d:%.2d",hour,minutes,seconds);
+        stime.sprintf("%.2d:%.2d:%.2d",hour,minutes,seconds);
         sdate+=stime;
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "pirmd.", "otrd.", "trešd.", "ceturtd.", "piektd.", "sestd.", "svētd." };
+      static const char *days_full[]    = { "pirmdiena", "otrdiena", "trešdiena", "ceturtdiena", "piektdiena", "sestdiena", "svētdiena" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "janv.", "febr.", "marts", "apr.", "maijs", "jūn.", "jūl.", "aug.", "sept.", "okt.", "nov.", "dec." };
+      static const char *months_full[]  = { "janvāris", "februāris", "marts", "aprīlis", "maijs", "jūnijs", "jūlijs", "augusts", "septembris", "oktobris", "novembris", "decembris" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "priekšp.", "pēcp." };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1944,15 +1962,6 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     {
       return "Metožu dokumentācija";
     }
-
-    /*! Used as the title of the design overview picture created for the
-     *  VHDL output.
-     */
-    virtual QCString trDesignOverview()
-    {
-      return "Dizaina pārskats";
-    }
-
 };
 
 #endif
