@@ -35,7 +35,7 @@
  files frees the maintainer from thinking about whether the
  first, the second, or both files should be included or not, and
  why.  This holds namely for localized translators because their
- base class is changed occasionaly to adapter classes when the
+ base class is changed occasionally to adapter classes when the
  Translator class changes the interface, or back to the
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
@@ -82,6 +82,10 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
     {
       return "sr-Cyrl";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0xC1A Serbian (Serbia, Cyrillic)";
+    }
 
     // --- Language translation methods -------------------
 
@@ -97,6 +101,10 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
     virtual QCString trDetailedDescription()
     { return "Опширније"; }
 
+    /*! header that is used when the summary tag is missing inside the details tag */
+    virtual QCString trDetails()
+    { return "Детаљи"; }
+
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return "Документација дефиниције типа"; }
@@ -147,7 +155,7 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
      */
     virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Аутоматски направљено помоћу Doxygen-а";
-      if (!s.isEmpty()) result+=(QCString)" за "+s;
+      if (!s.isEmpty()) result+=" за "+s;
       result+=" из изворног кода.";
       return result;
     }
@@ -395,6 +403,10 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
       {
         return "Документација структуре";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Документација класе";
@@ -413,12 +425,6 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
     virtual QCString trExampleDocumentation()
     { return "Документација примера"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Документација странице"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Приручник"; }
@@ -509,22 +515,18 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
      */
     virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Направљено "+date;
-      if (!projName.isEmpty()) result+=(QCString)" за "+projName;
-      result+=(QCString)" помоћу";
+      QCString result="Направљено "+date;
+      if (!projName.isEmpty()) result+=" за "+projName;
+      result+=" помоћу";
       return result;
     }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Дијаграм наслеђивања за "+clName+":";
+      return "Дијаграм наслеђивања за "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Само за унутрашњу употребу."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Упозорење"; }
@@ -599,7 +601,7 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isTemplate)
       {
         result+=" Шаблон";
@@ -776,7 +778,7 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Документација за ";
+      QCString result="Документација за ";
       switch(compType)
       {
         case ClassDef::Class:      result+="ову класу"; break;
@@ -841,12 +843,12 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Дијаграм сарадње за "+clName+":";
+      return "Дијаграм сарадње за "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Дијаграм зависности укључивања за "+fName+":";
+      return "Дијаграм зависности укључивања за "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1127,12 +1129,7 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Пакет "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Списак пакета";
+      return "Пакет "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1389,14 +1386,18 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Функције пакета";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Чланови пакета";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Статичке функције пакета";
     }
@@ -1520,14 +1521,6 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
     virtual QCString trDirectories()
     { return "Директоријуми"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Ова хијерархија директоријума је уређена "
-             "приближно по абецеди:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1662,7 +1655,7 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isTemplate) result+=" Шаблон";
       result+=" Референца";
       switch(compType)
@@ -1730,7 +1723,7 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Документација за ";
+      QCString result="Документација за ";
       switch(compType)
       {
         case ClassDef::Class:      result+="овај модул"; break;
@@ -1773,6 +1766,25 @@ class TranslatorSerbianCyrillic : public TranslatorAdapter_1_6_0
       return "Ограничења типова";
     }
 
+    virtual QCString trDayOfWeek(int dayOfWeek, bool, bool full)
+    {
+      static const char *days_short[] = { "пон", "уто", "сри", "чет", "пет", "суб", "нед" };
+      static const char *days_full[] = { "Понедељак", "Уторак", "Среда", "Четвртак", "Петак", "Субота", "Недеља" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      return text;
+    }
+    virtual QCString trMonth(int month, bool, bool full)
+    {
+      static const char *months_short[] = { "Јан", "Феб", "Мар", "Апр", "Мај", "Јун", "Јул", "Авг", "Сеп", "Окт", " новембар", "дец" };
+      static const char *months_full[] = { "јануар", "фебруар", "март", "април", "мај", "јун", "јул", "август", "септембар", "октобар", " Новембар Децембар" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "пре подне", "по подне" };
+      return dayPeriod[period];
+    }
 };
 
 #endif
