@@ -35,6 +35,10 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     {
       return "uk";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x422 Ukrainian";
+    }
 
     // --- Language translation methods -------------------
 
@@ -50,6 +54,10 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     virtual QCString trDetailedDescription()
     { return "Детальний опис"; }
 
+    /*! header that is used when the summary tag is missing inside the details tag */
+    virtual QCString trDetails()
+    { return "Подробиці"; }
+
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return "Опис типів користувача"; }
@@ -334,6 +342,10 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
       {
         return  "Структури даних" ;
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return  "Класи" ;
@@ -352,12 +364,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     virtual QCString trExampleDocumentation()
     { return "Приклади"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Документація по темі"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Довідковий посібник"; }
@@ -465,10 +471,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
       return QCString("Схема успадкувань для ")+clName;
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Тільки для внутрішнього користування"; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Застереження"; }
@@ -717,7 +719,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Документація  ";
+      QCString result="Документація  ";
       switch(compType)
       {
         case ClassDef::Class:
@@ -797,7 +799,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Діаграма зв'язків класу "+clName+":";
+      return "Діаграма зв'язків класу "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
@@ -1082,11 +1084,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     {
       return QCString("Пакет ")+name;
     }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Повний список пакетів";
-    }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
     {
@@ -1322,15 +1319,19 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Функції пакетів";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Елементи пакетів";
+    }
 
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Статичні функцію пакетів";
     }
@@ -1444,14 +1445,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     virtual QCString trDirectories()
     { return "Каталоги"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Дерево каталогів впорядковано наближено "
-	     "до алфавіту:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1587,7 +1580,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isTemplate)
       {
 	switch(compType)
@@ -1672,7 +1665,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Документацію для ";
+      QCString result="Документацію для ";
       switch(compType)
       {
         case ClassDef::Class:      result+="цього модуля"; break;
@@ -1761,7 +1754,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Файл у "+name;
+      return "Файл у "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
@@ -1770,7 +1763,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Включає файли в "+name;
+      return "Включає файли в "+name;
     }
 
     /** Compiles a date string.
@@ -1785,20 +1778,43 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
                                 int hour,int minutes,int seconds,
-                                bool includeTime)
+                                DateTimeType includeTime)
     {
       static const char *days[]   = { "Понеділок","Вівторок","Середа","Четвер","П'ятниця","Субота","Неділя" };
       static const char *months[] = { "січня","лютого","березня","квітня","травня","червня","липня","серпня","вересня","жотня","листопада","грудня" };
       QCString sdate;
-      sdate.sprintf("%s, %d %s %d",days[dayOfWeek-1],day,months[month-1],year);
-      if (includeTime)
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Date)
+      {
+        sdate.sprintf("%s, %d %s %d",days[dayOfWeek-1],day,months[month-1],year);
+      }
+      if (includeTime == DateTimeType::DateTime) sdate += " ";
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Time)
       {
         QCString stime;
-        stime.sprintf(" %.2d:%.2d:%.2d",hour,minutes,seconds);
+        stime.sprintf("%.2d:%.2d:%.2d",hour,minutes,seconds);
         sdate+=stime;
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool, bool full)
+    {
+      static const char *days_short[]   = { "Пн", "Вт", "Ср", "Чт", "Пт", "Сб", "Нд" };
+      static const char *days_full[]    = { "понеділок", "вівторок", "середа", "четвер", "п'ятниця", "субота", "неділя" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      return text;
+    }
+    virtual QCString trMonth(int month, bool, bool full)
+    {
+      static const char *months_short[] = { "Січ", "Лют", "Бер", "Кві", "Тра", "Чер", "Лип", "Сер", "Вер", "Жов", "Лис", "Гру" };
+      static const char *months_full[]  = { "січень", "лютий", "березень", "квітень", "травень", "червень", "липень", "серпень", "вересень", "жовтень", "листопад", "грудень" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "дп", "пп" };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1908,15 +1924,6 @@ class TranslatorUkrainian : public TranslatorAdapter_1_8_4
     {
       return "Документація метода";
     }
-
-    /*! Used as the title of the design overview picture created for the
-     *  VHDL output.
-     */
-    virtual QCString trDesignOverview()
-    {
-      return "Огляд дизайну проекту";
-    }
-
 };
 
 #endif
