@@ -63,6 +63,10 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
     {
       return "af";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x436 Afrikaans";
+    }
 
     // --- Language translation methods -------------------
 
@@ -78,6 +82,10 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
     virtual QCString trDetailedDescription()
     { return "Detail Beskrywing"; }
 
+    /*! header that is used when the summary tag is missing inside the details tag */
+    virtual QCString trDetails()
+    { return "Besonderhede"; }
+
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return "Lede Typedef Dokumentasie"; }
@@ -128,7 +136,7 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
      */
     virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Automaties gegenereer deur Doxygen";
-      if (!s.isEmpty()) result+=(QCString)" vir "+s;
+      if (!s.isEmpty()) result+=" vir "+s;
       result+=" van die bron kode af.";
       return result;
     }
@@ -374,6 +382,10 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
       {
         return "Data Strukture Dokumentasie";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Klas Dokumentasie";
@@ -392,12 +404,6 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
     virtual QCString trExampleDocumentation()
     { return "Voorbeeld Dokumentasie"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Bladsy Dokumentasie"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Verwysings Handleiding"; }
@@ -488,22 +494,18 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
      */
     virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Gegenereer op "+date;
-      if (!projName.isEmpty()) result+=(QCString)" vir "+projName;
-      result+=(QCString)" deur";
+      QCString result="Gegenereer op "+date;
+      if (!projName.isEmpty()) result+=" vir "+projName;
+      result+=" deur";
       return result;
     }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Afleidings diagram vir "+clName+":";
+      return "Afleidings diagram vir "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Slegs vir interne gebruik."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Waarskuwing"; }
@@ -578,7 +580,7 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" klas"; break;
@@ -738,7 +740,7 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Die dokumentasie vir hierdie ";
+      QCString result="Die dokumentasie vir hierdie ";
       switch(compType)
       {
         case ClassDef::Class:      result+="klas"; break;
@@ -803,12 +805,12 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Samewerkings diagram vir "+clName+":";
+      return "Samewerkings diagram vir "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Insluitings afhanklikheid diagram vir "+fName+":";
+      return "Insluitings afhanklikheid diagram vir "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1089,12 +1091,7 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Pakket "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Pakket Lys";
+      return "Pakket "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1351,14 +1348,18 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Pakket Funksies";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Pakket Lede";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statiese Pakket Funksies";
     }
@@ -1470,14 +1471,6 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
     virtual QCString trDirectories()
     { return "Directories"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Hierdie directory hiërargie is min of meer alfabeties "
-             "gesorteer:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1613,7 +1606,7 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Module"; break;
@@ -1681,7 +1674,7 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"The documentation for this ";
+      QCString result="The documentation for this ";
       switch(compType)
       {
         case ClassDef::Class:      result+="module"; break;
@@ -1724,6 +1717,27 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
       return "Tipe Limiete";
     }
 
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "Ma.", "Di.", "Wo.", "Do.", "Vr.", "Sa.", "So." };
+      static const char *days_full[]    = { "Maandag", "Dinsdag", "Woensdag", "Donderdag", "Vrydag", "Saterdag", "Sondag" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "Jan.", "Feb.", "Mrt.", "Apr.", "Mei", "Jun.", "Jul.", "Aug.", "Sep.", "Okt.", "Nov.", "Des." };
+      static const char *months_full[]  = { "Januarie", "Februarie", "Maart", "April", "Mei", "Junie", "Julie", "Augustus", "September", "Oktober", "November", "Desember" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "vm.", "nm." };
+      return dayPeriod[period];
+    }
 };
 
 #endif
